@@ -1,5 +1,3 @@
-context("lm_effsize_ci")
-
 # lm_effsize_ci works (eta, partial = FALSE) --------------------------------
 
 testthat::test_that(
@@ -429,7 +427,8 @@ testthat::test_that(
     )
 
     # model-3
-    testthat::expect_equal(c(df3$partial.omegasq[[1]], df3$partial.omegasq[[2]]),
+    testthat::expect_equal(
+      c(df3$partial.omegasq[[1]], df3$partial.omegasq[[2]]),
       c(0.2565812, 0.1041597),
       tolerance = 0.001
     )
@@ -449,79 +448,81 @@ testthat::test_that(
 
 # lm_effsize_ci works with ezANOVA -----------------------------------
 
-testthat::test_that(
-  desc = "lm_effsize_ci works with ezANOVA",
-  code = {
-    testthat::skip_if(getRversion() < "3.6")
+if (require("ez")) {
+  testthat::test_that(
+    desc = "lm_effsize_ci works with ezANOVA",
+    code = {
+      testthat::skip_if(getRversion() < "3.6")
 
-    set.seed(123)
-    library(ez)
-    data(ANT)
+      set.seed(123)
+      library(ez)
+      data(ANT)
 
-    # run an ANOVA on the mean correct RT data.
-    rt_anova <- suppressWarnings(ez::ezANOVA(
-      data = ANT[ANT$error == 0, ],
-      dv = rt,
-      wid = subnum,
-      within = cue,
-      detailed = TRUE,
-      return_aov = TRUE
-    ))
+      # run an ANOVA on the mean correct RT data.
+      rt_anova <- suppressWarnings(ez::ezANOVA(
+        data = ANT[ANT$error == 0, ],
+        dv = rt,
+        wid = subnum,
+        within = cue,
+        detailed = TRUE,
+        return_aov = TRUE
+      ))
 
-    # dataframe with effect sizes
-    set.seed(123)
-    df1 <- groupedstats::lm_effsize_ci(
-      object = rt_anova$aov,
-      effsize = "eta",
-      partial = TRUE,
-      nboot = 25
-    )
+      # dataframe with effect sizes
+      set.seed(123)
+      df1 <- groupedstats::lm_effsize_ci(
+        object = rt_anova$aov,
+        effsize = "eta",
+        partial = TRUE,
+        nboot = 25
+      )
 
-    set.seed(123)
-    df2 <- suppressWarnings(groupedstats::lm_effsize_ci(
-      object = rt_anova$aov,
-      effsize = "eta",
-      partial = FALSE,
-      nboot = 25
-    ))
+      set.seed(123)
+      df2 <- suppressWarnings(groupedstats::lm_effsize_ci(
+        object = rt_anova$aov,
+        effsize = "eta",
+        partial = FALSE,
+        nboot = 25
+      ))
 
-    set.seed(123)
-    df3 <- suppressWarnings(groupedstats::lm_effsize_ci(
-      object = rt_anova$aov,
-      effsize = "omega",
-      partial = TRUE,
-      nboot = 25
-    ))
+      set.seed(123)
+      df3 <- suppressWarnings(groupedstats::lm_effsize_ci(
+        object = rt_anova$aov,
+        effsize = "omega",
+        partial = TRUE,
+        nboot = 25
+      ))
 
-    set.seed(123)
-    df4 <- groupedstats::lm_effsize_ci(
-      object = rt_anova$aov,
-      effsize = "omega",
-      partial = FALSE,
-      nboot = 25
-    )
+      set.seed(123)
+      df4 <- groupedstats::lm_effsize_ci(
+        object = rt_anova$aov,
+        effsize = "omega",
+        partial = FALSE,
+        nboot = 25
+      )
 
-    # df1
-    testthat::expect_equal(df1$partial.etasq[[1]], 0.9596874, tolerance = 0.001)
-    testthat::expect_equal(df1$conf.low[[1]], 0.9355735, tolerance = 0.001)
-    testthat::expect_equal(df1$conf.high[[1]], 0.9692072, tolerance = 0.001)
+      # df1
+      testthat::expect_equal(df1$partial.etasq[[1]], 0.9596874, tolerance = 0.001)
+      testthat::expect_equal(df1$conf.low[[1]], 0.9355735, tolerance = 0.001)
+      testthat::expect_equal(df1$conf.high[[1]], 0.9692072, tolerance = 0.001)
 
-    # df2
-    testthat::expect_equal(df2$etasq[[1]], 0.9401073, tolerance = 0.001)
-    testthat::expect_equal(df2$conf.low[[1]], 0.01308266, tolerance = 0.001)
-    testthat::expect_equal(df2$conf.high[[1]], 0.04279811, tolerance = 0.001)
+      # df2
+      testthat::expect_equal(df2$etasq[[1]], 0.9401073, tolerance = 0.001)
+      testthat::expect_equal(df2$conf.low[[1]], 0.01308266, tolerance = 0.001)
+      testthat::expect_equal(df2$conf.high[[1]], 0.04279811, tolerance = 0.001)
 
-    # df3
-    testthat::expect_equal(df3$partial.omegasq[[1]], 0.9442101, tolerance = 0.001)
-    testthat::expect_equal(df3$conf.low[[1]], 1, tolerance = 0.001)
-    testthat::expect_equal(df3$conf.high[[1]], 1, tolerance = 0.001)
+      # df3
+      testthat::expect_equal(df3$partial.omegasq[[1]], 0.9442101, tolerance = 0.001)
+      testthat::expect_equal(df3$conf.low[[1]], 1, tolerance = 0.001)
+      testthat::expect_equal(df3$conf.high[[1]], 1, tolerance = 0.001)
 
-    # df4
-    testthat::expect_equal(df4$omegasq[[1]], 0.9373795, tolerance = 0.001)
-    testthat::expect_equal(df4$conf.low[[1]], 0.9171685, tolerance = 0.001)
-    testthat::expect_equal(df4$conf.high[[1]], 0.9599996, tolerance = 0.001)
-  }
-)
+      # df4
+      testthat::expect_equal(df4$omegasq[[1]], 0.9373795, tolerance = 0.001)
+      testthat::expect_equal(df4$conf.low[[1]], 0.9171685, tolerance = 0.001)
+      testthat::expect_equal(df4$conf.high[[1]], 0.9599996, tolerance = 0.001)
+    }
+  )
+}
 
 # lm_effsize_standardizer works --------------------------------
 
@@ -533,36 +534,40 @@ testthat::test_that(
 
     # creating lm object-1
     set.seed(123)
-    df1 <- groupedstats::lm_effsize_standardizer(
-      object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
-      effsize = "eta",
-      partial = FALSE,
-      nboot = 20
-    )
+    df1 <-
+      groupedstats::lm_effsize_standardizer(
+        object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
+        effsize = "eta",
+        partial = FALSE,
+        nboot = 20
+      )
 
     set.seed(123)
-    df2 <- groupedstats::lm_effsize_standardizer(
-      object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
-      effsize = "eta",
-      partial = TRUE,
-      nboot = 20
-    )
+    df2 <-
+      groupedstats::lm_effsize_standardizer(
+        object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
+        effsize = "eta",
+        partial = TRUE,
+        nboot = 20
+      )
 
     set.seed(123)
-    df3 <- groupedstats::lm_effsize_standardizer(
-      object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
-      effsize = "omega",
-      partial = FALSE,
-      nboot = 20
-    )
+    df3 <-
+      groupedstats::lm_effsize_standardizer(
+        object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
+        effsize = "omega",
+        partial = FALSE,
+        nboot = 20
+      )
 
     set.seed(123)
-    df4 <- groupedstats::lm_effsize_standardizer(
-      object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
-      effsize = "omega",
-      partial = TRUE,
-      nboot = 20
-    )
+    df4 <-
+      groupedstats::lm_effsize_standardizer(
+        object = stats::lm(formula = brainwt ~ vore, data = ggplot2::msleep),
+        effsize = "omega",
+        partial = TRUE,
+        nboot = 20
+      )
 
     testthat::expect_equal(df1$F.value, df2$F.value, tolerance = 0.0001)
     testthat::expect_equal(df3$p.value, df4$p.value, tolerance = 0.0001)
